@@ -1,43 +1,38 @@
-# ABSTRACT: Perl 5 API wrapper for Facebook.com
+# ABSTRACT: Facebook.com API Client
 package API::Facebook;
 
-use API::Facebook::Class;
+use namespace::autoclean -except => 'has';
 
-extends 'API::Facebook::Client';
+use Data::Object::Class;
+use Data::Object::Class::Syntax;
+use Data::Object::Signatures;
 
-use Carp ();
-use Scalar::Util ();
+use Data::Object qw(load);
+use Data::Object::Library qw(Str);
 
-our $VERSION = '0.01'; # VERSION
+extends 'API::Client';
 
-has access_token => (
-    is       => 'rw',
-    isa      => Str,
-    required => 0,
-);
+our $VERSION = '0.02'; # VERSION
 
-has identifier => (
-    is       => 'rw',
-    isa      => Str,
-    default  => 'API::Facebook (Perl)',
-);
+our $DEFAULT_URL = "https://graph.facebook.com";
 
-has version => (
-    is       => 'rw',
-    isa      => Str,
-    default  => '2.4',
-);
+# ATTRIBUTES
 
-method AUTOLOAD () {
-    my ($package, $method) = our $AUTOLOAD =~ /^(.+)::(.+)$/;
-    Carp::croak "Undefined subroutine &${package}::$method called"
-        unless Scalar::Util::blessed $self && $self->isa(__PACKAGE__);
+has access_token => rw;
 
-    # return new resource instance dynamically
-    return $self->resource($method, @_);
-}
+# CONSTRAINTS
 
-method BUILD () {
+req access_token => Str;
+
+# DEFAULTS
+
+def identifier => 'API::Facebook (Perl)';
+def url        => method { load('Mojo::URL')->new($DEFAULT_URL) };
+def version    => 1;
+
+# CONSTRUCTION
+
+after BUILD => method {
     my $identifier = $self->identifier;
     my $version    = $self->version;
     my $agent      = $self->user_agent;
@@ -47,7 +42,9 @@ method BUILD () {
     $url->path("/v$version");
 
     return $self;
-}
+};
+
+# METHODS
 
 method PREPARE ($ua, $tx, %args) {
     my $headers = $tx->req->headers;
@@ -60,28 +57,6 @@ method PREPARE ($ua, $tx, %args) {
     $url->query->merge(access_token => $self->access_token) if $self->access_token;
 }
 
-method action ($method, %args) {
-    $method = uc($method || 'get');
-
-    # execute transaction and return response
-    return $self->$method(%args);
-}
-
-method create (%args) {
-    # execute transaction and return response
-    return $self->POST(%args);
-}
-
-method delete (%args) {
-    # execute transaction and return response
-    return $self->DELETE(%args);
-}
-
-method fetch (%args) {
-    # execute transaction and return response
-    return $self->GET(%args);
-}
-
 method resource (@segments) {
     # build new resource instance
     my $instance = __PACKAGE__->new(
@@ -106,11 +81,6 @@ method resource (@segments) {
     return $instance;
 }
 
-method update (%args) {
-    # execute transaction and return response
-    return $self->PUT(%args);
-}
-
 1;
 
 __END__
@@ -121,11 +91,11 @@ __END__
 
 =head1 NAME
 
-API::Facebook - Perl 5 API wrapper for Facebook.com
+API::Facebook - Facebook.com API Client
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -151,175 +121,26 @@ version 0.01
 This distribution provides an object-oriented thin-client library for
 interacting with the Facebook (L<http://facebook.com>) API. For usage and
 documentation information visit L<https://developers.facebook.com/docs/graph-api>.
+API::Facebook is derived from L<API::Client> and inherits all of it's
+functionality. Please read the documentation for API::Client for more usage
+information.
 
-=head1 THIN CLIENT
-
-A thin-client library is advantageous as it has complete API coverage and
-can easily adapt to changes in the API with minimal effort. As a thin-client
-library, this module does not map specific HTTP requests to specific routines,
-nor does it provide parameter validation, pagination, or other conventions
-found in typical API client implementations, instead, it simply provides a
-simple and consistent mechanism for dynamically generating HTTP requests.
-Additionally, this module has support for debugging and retrying API calls as
-well as throwing exceptions when 4xx and 5xx server response codes are
-returned.
-
-=head2 Building
-
-    my $feed = $facebook->me('feed');
-
-    $feed->action;          # GET   /me/feed
-    $feed->action('head');  # HEAD  /me/feed
-    $feed->action('patch'); # PATCH /me/feed
-
-Building up an HTTP request object is extremely easy, simply call method names
-which correspond to the API's path segments in the resource you wish to execute
-a request against. This module uses autoloading and returns a new instance with
-each method call. The following is the equivalent:
-
-=head2 Chaining
-
-    my $me = $facebook->resource('me');
-
-    # or
-
-    my $me   = $facebook->me;
-    my $feed = $me->resource('feed');
-
-    # then
-
-    $feed->action('put', %args); # PUT /me/feed
-
-Because each call returns a new API instance configured with a resource locator
-based on the supplied parameters, reuse and request isolation are made simple,
-i.e., you will only need to configure the client once in your application.
-
-=head2 Fetching
-
-    my $me = $facebook->me;
-
-    # query-string parameters
-
-    $me->fetch( query => { ... } );
-
-    # equivalent to
-
-    my $me = $facebook->resource('me');
-
-    $me->action( get => ( query => { ... } ) );
-
-This example illustrates how you might fetch an API resource.
-
-=head2 Creating
-
-    my $me = $facebook->me;
-
-    # content-body parameters
-
-    $me->create( data => { ... } );
-
-    # query-string parameters
-
-    $me->create( query => { ... } );
-
-    # equivalent to
-
-    $facebook->resource('me')->action(
-        post => ( query => { ... }, data => { ... } )
-    );
-
-This example illustrates how you might create a new API resource.
-
-=head2 Updating
-
-    my $me = $facebook->me;
-    my $feed = $me->resource('feed');
-
-    # content-body parameters
-
-    $feed->update( data => { ... } );
-
-    # query-string parameters
-
-    $feed->update( query => { ... } );
-
-    # or
-
-    my $feed = $facebook->me('feed');
-
-    $feed->update( ... );
-
-    # equivalent to
-
-    $facebook->resource('me')->action(
-        put => ( query => { ... }, data => { ... } )
-    );
-
-This example illustrates how you might update a new API resource.
-
-=head2 Deleting
-
-    my $me   = $facebook->me;
-    my $feed = $me->resource('feed');
-
-    # content-body parameters
-
-    $feed->delete( data => { ... } );
-
-    # query-string parameters
-
-    $feed->delete( query => { ... } );
-
-    # or
-
-    my $feed = $facebook->me('feed');
-
-    $feed->delete( ... );
-
-    # equivalent to
-
-    $facebook->resource('me')->action(
-        delete => ( query => { ... }, data => { ... } )
-    );
-
-This example illustrates how you might delete an API resource.
-
-=head2 Transacting
-
-    my $feed = $facebook->resource('me', 'feed');
-
-    my ($results, $transaction) = $feed->action( ... );
-
-    my $request  = $transaction->req;
-    my $response = $transaction->res;
-
-    my $headers;
-
-    $headers = $request->headers;
-    $headers = $response->headers;
-
-    # etc
-
-This example illustrates how you can access the transaction object used
-represent and process the HTTP transaction.
-
-=head1 PARAMETERS
+=head1 ATTRIBUTES
 
 =head2 access_token
 
     $facebook->access_token;
     $facebook->access_token('ACCESS_TOKEN');
 
-The access_token parameter should be set to an API access token associated with your account.
+The access_token attribute should be set to an API access token associated with
+your account.
 
 =head2 identifier
 
     $facebook->identifier;
     $facebook->identifier('IDENTIFIER');
 
-The identifier parameter should be set to a string that identifies your app.
-
-=head1 ATTRIBUTES
+The identifier attribute should be set to a string that identifies your app.
 
 =head2 debug
 
